@@ -527,14 +527,14 @@ def os_backup(backup,output):
         # sudo chmod +x pishrink.sh
 
     ret,msg = run_shell_command('sudo bash {}/pishrink.sh -z {}/{}'.format(working_dir,os_backup_location,backup_name))
-    ret,msg = run_shell_command('sudo chown pi:pi *.img.gz')
+    ret,msg = run_shell_command('sudo chown pi:pi {}/*.img.gz'.format(os_backup_location))
 
     # old bkp cleanup
     existing_backup_dir = glob.glob('{}/*'.format(os_backup_location))
     existing_backup_dir.sort()
     for out_file in existing_backup_dir:
         if out_file not in existing_backup_dir[-4:]:
-            print("Deleting {}".format(out_file))
+            logger.info("Deleting {}".format(out_file))
             shutil.rmtree(out_file,ignore_errors=True)
 
     return(output)
